@@ -10,16 +10,18 @@
 
 #define QT_FEATURE_evr -1
 
-#define QT_FEATURE_gstreamer_1_0 1
-
 #define QT_FEATURE_gstreamer 1
 
-#define QT_FEATURE_gstreamer_app 1
-
 #define QT_FEATURE_gstreamer_photography 1
 
 #define QT_FEATURE_gstreamer_gl 1
 
+#define QT_FEATURE_gstreamer_gl_wayland 1
+
+#define QT_FEATURE_gstreamer_gl_egl 1
+
+#define QT_FEATURE_gstreamer_gl_x11 1
+
 #define QT_FEATURE_gpu_vivante -1
 
 #define QT_FEATURE_linux_v4l -1
